@@ -11,23 +11,23 @@ App::Math::Tutor::Cmd::VulFrac::Cmd::Add - Plugin for addition and subtraction o
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moo;
 use MooX::Cmd;
 use MooX::Options;
 
 has template_filename => (
-                           is      => "ro",
-                           default => "twocols"
-                         );
+    is      => "ro",
+    default => "twocols"
+);
 
 with "App::Math::Tutor::Role::VulFracExercise";
 
 my %result_formats = (
-                       keep      => 1,
-                       reducable => 1,
-                     );
+    keep      => 1,
+    reducable => 1,
+);
 
 =head1 ATTRIBUTES
 
@@ -50,32 +50,28 @@ option result_format => (
         my ( @fail, %rf );
         $rf{$_} = defined $result_formats{$_} or push @fail, $_ foreach @{ $_[0] };
         @fail
-          and die "Invalid result format: "
-          . join( ", ", @fail )
-          . ", pick any of "
-          . join( ", ", keys %result_formats );
-        return \%rf;
+          and die "Invalid result format: " . join( ", ", @fail ) . ", pick any of " . join( ", ", keys %result_formats );
+        \%rf;
     },
     format     => "s@",
     autosplit  => ",",
     repeatable => 1,
     short      => "r",
-                        );
+);
 
-sub _build_command_names
-{
-    return qw(add sub);
-}
+sub _build_command_names { qw(add sub); }
 
 my $a_plus_b = sub {
-    return
-      PolyNum->new( operator => $_[0],
-                    values   => [ splice @_, 1 ] );
+    PolyNum->new(
+        operator => $_[0],
+        values   => [ splice @_, 1 ]
+    );
 };
 my $a_mult_b = sub {
-    return
-      ProdNum->new( operator => $_[0],
-                    values   => [ splice @_, 1 ] );
+    ProdNum->new(
+        operator => $_[0],
+        values   => [ splice @_, 1 ]
+    );
 };
 
 sub _operands_ok
@@ -89,25 +85,26 @@ sub _operands_ok
         my $a = $s->_reduce;
         $b = $b->_reduce;
         my $gcd = VulFrac->new(
-                                num   => $a->denum,
-                                denum => $b->denum
-                              )->_gcd;
+            num   => $a->denum,
+            denum => $b->denum
+        )->_gcd;
         my ( $fa, $fb ) = ( $b->{denum} / $gcd, $a->{denum} / $gcd );
         my ( $xa, $xb ) = (
-                            VulFrac->new(
-                                          num   => int( $a_mult_b->( '*', $a->num,   $fa ) ),
-                                          denum => int( $a_mult_b->( '*', $a->denum, $fa ) ),
-                                          sign  => $a->sign
-                                        ),
-                            VulFrac->new(
-                                          num   => int( $a_mult_b->( '*', $b->num,   $fb ) ),
-                                          denum => int( $a_mult_b->( '*', $b->denum, $fb ) ),
-                                          sign  => $b->sign
-                                        )
-                          );
+            VulFrac->new(
+                num   => int( $a_mult_b->( '*', $a->num,   $fa ) ),
+                denum => int( $a_mult_b->( '*', $a->denum, $fa ) ),
+                sign  => $a->sign
+            ),
+            VulFrac->new(
+                num   => int( $a_mult_b->( '*', $b->num,   $fb ) ),
+                denum => int( $a_mult_b->( '*', $b->denum, $fb ) ),
+                sign  => $b->sign
+            )
+        );
         $s = VulFrac->new(
-                     num   => int( $a_plus_b->( $op, $xa->sign * $xa->num, $xb->sign * $xb->num ) ),
-                     denum => $xa->denum );
+            num   => int( $a_plus_b->( $op, $xa->sign * $xa->num, $xb->sign * $xb->num ) ),
+            denum => $xa->denum
+        );
     }
     my ( $max_num, $max_denum ) = ( @{ $_[0]->format } );
     my %result_format = %{ $self->result_format };
@@ -115,7 +112,7 @@ sub _operands_ok
     $s = $s->_reduce;
     $s->num <= $max_num     or return 0 if defined $result_format{keep} and $result_format{keep};
     $s->denum <= $max_denum or return 0 if defined $result_format{keep} and $result_format{keep};
-    return 1;
+    1;
 }
 
 sub _build_exercises
@@ -137,13 +134,13 @@ sub _build_exercises
     }
 
     my $exercises = {
-                      section => "Vulgar fraction addition / subtraction",
-                      caption => 'Fractions',
-                      label   => 'vulgar_fractions_addition',
-                      header  => [ [ 'Vulgar Fraction Addition', 'Vulgar Fraction Subtraction' ] ],
-                      solutions  => [],
-                      challenges => [],
-                    };
+        section    => "Vulgar fraction addition / subtraction",
+        caption    => 'Fractions',
+        label      => 'vulgar_fractions_addition',
+        header     => [ [ 'Vulgar Fraction Addition', 'Vulgar Fraction Subtraction' ] ],
+        solutions  => [],
+        challenges => [],
+    };
     # use Text::TabularDisplay;
     # my $table = Text::TabularDisplay->new( 'Bruch -> Dez', 'Dez -> Bruch' );
     foreach my $line (@tasks)
@@ -164,46 +161,47 @@ sub _build_exercises
               if ( $a->_gcd > 1 or $b->_gcd > 1 );
 
             my $gcd = VulFrac->new(
-                                    num   => $a->denum,
-                                    denum => $b->denum
-                                  )->_gcd;
+                num   => $a->denum,
+                denum => $b->denum
+            )->_gcd;
             my ( $fa, $fb ) = ( $b->{denum} / $gcd, $a->{denum} / $gcd );
 
             my ( $xa, $xb ) = (
-                                VulFrac->new(
-                                              num   => $a_mult_b->( '*', $a->num,   $fa ),
-                                              denum => $a_mult_b->( '*', $a->denum, $fa ),
-                                              sign  => $a->sign
-                                            ),
-                                VulFrac->new(
-                                              num   => $a_mult_b->( '*', $b->num,   $fb ),
-                                              denum => $a_mult_b->( '*', $b->denum, $fb ),
-                                              sign  => $b->sign
-                                            )
-                              );
+                VulFrac->new(
+                    num   => $a_mult_b->( '*', $a->num,   $fa ),
+                    denum => $a_mult_b->( '*', $a->denum, $fa ),
+                    sign  => $a->sign
+                ),
+                VulFrac->new(
+                    num   => $a_mult_b->( '*', $b->num,   $fb ),
+                    denum => $a_mult_b->( '*', $b->denum, $fb ),
+                    sign  => $b->sign
+                )
+            );
             push @way, $a_plus_b->( $op, $xa, $xb );
             $xa = VulFrac->new(
-                                num   => int( $xa->num ),
-                                denum => int( $xa->denum ),
-                                sign  => $xa->sign
-                              );
+                num   => int( $xa->num ),
+                denum => int( $xa->denum ),
+                sign  => $xa->sign
+            );
             $xb = VulFrac->new(
-                                num   => int( $xb->num ),
-                                denum => int( $xb->denum ),
-                                sign  => $xb->sign
-                              );
+                num   => int( $xb->num ),
+                denum => int( $xb->denum ),
+                sign  => $xb->sign
+            );
             push @way, $a_plus_b->( $op, $xa, $xb );
 
             my $s = VulFrac->new(
-                            num   => $a_plus_b->( $op, $xa->sign * $xa->num, $xb->sign * $xb->num ),
-                            denum => $xa->denum );
+                num   => $a_plus_b->( $op, $xa->sign * $xa->num, $xb->sign * $xb->num ),
+                denum => $xa->denum
+            );
 
             push @way, $s;
             $s = VulFrac->new(
-                               num   => int( $s->num ),
-                               denum => $s->denum,
-                               sign  => $s->sign
-                             );
+                num   => int( $s->num ),
+                denum => $s->denum,
+                sign  => $s->sign
+            );
             push @way, "" . $s;
             $s->_gcd > 1 and $s = $s->_reduce and push @way, $s;
 
@@ -216,7 +214,7 @@ sub _build_exercises
         push( @{ $exercises->{challenges} }, \@challenge );
     }
 
-    return $exercises;
+    $exercises;
 }
 
 =head1 LICENSE AND COPYRIGHT
