@@ -11,23 +11,23 @@ App::Math::Tutor::Cmd::VulFrac::Cmd::Mul - Plugin for multiplication and divisio
 
 =cut
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moo;
 use MooX::Cmd;
 use MooX::Options;
 
 has template_filename => (
-                           is      => "ro",
-                           default => "twocols"
-                         );
+    is      => "ro",
+    default => "twocols"
+);
 
 with "App::Math::Tutor::Role::VulFracExercise";
 
 my %result_formats = (
-                       keep      => 1,
-                       reducable => 1,
-                     );
+    keep      => 1,
+    reducable => 1,
+);
 
 =head1 ATTRIBUTES
 
@@ -50,27 +50,22 @@ option result_format => (
         my ( @fail, %rf );
         $rf{$_} = defined $result_formats{$_} or push @fail, $_ foreach @{ $_[0] };
         @fail
-          and die "Invalid result format: "
-          . join( ", ", @fail )
-          . ", pick any of "
-          . join( ", ", keys %result_formats );
-        return \%rf;
+          and die "Invalid result format: " . join( ", ", @fail ) . ", pick any of " . join( ", ", keys %result_formats );
+        \%rf;
     },
     format     => "s@",
     autosplit  => ",",
     repeatable => 1,
     short      => "r",
-                        );
+);
 
-sub _build_command_names
-{
-    return qw(mul div);
-}
+sub _build_command_names { qw(mul div); }
 
 my $a_mult_b = sub {
-    return
-      ProdNum->new( operator => $_[0],
-                    values   => [ splice @_, 1 ] );
+    ProdNum->new(
+        operator => $_[0],
+        values   => [ splice @_, 1 ]
+    );
 };
 
 sub _operands_ok
@@ -85,8 +80,9 @@ sub _operands_ok
         $b = $b->_reduce;
         $op eq "/" and $b = $b->_reciprocal;
         $s = VulFrac->new(
-                         num   => int( $a_mult_b->( "*", $a->sign * $a->num, $b->sign * $b->num ) ),
-                         denum => int( $a_mult_b->( "*", $a->denum,          $b->denum ) ) );
+            num   => int( $a_mult_b->( "*", $a->sign * $a->num, $b->sign * $b->num ) ),
+            denum => int( $a_mult_b->( "*", $a->denum,          $b->denum ) )
+        );
     }
     my ( $max_num, $max_denum ) = ( @{ $_[0]->format } );
     my %result_format = %{ $self->result_format };
@@ -94,7 +90,7 @@ sub _operands_ok
     $s = $s->_reduce;
     $s->num <= $max_num     or return 0 if defined $result_format{keep} and $result_format{keep};
     $s->denum <= $max_denum or return 0 if defined $result_format{keep} and $result_format{keep};
-    return 1;
+    1;
 }
 
 sub _build_exercises
@@ -115,13 +111,13 @@ sub _build_exercises
     }
 
     my $exercises = {
-                     section => "Vulgar fraction multiplication / division",
-                     caption => 'Fractions',
-                     label   => 'vulgar_fractions_multiplication',
-                     header => [ [ 'Vulgar Fraction Multiplication', 'Vulgar Fraction Division' ] ],
-                     solutions  => [],
-                     challenges => [],
-                    };
+        section    => "Vulgar fraction multiplication / division",
+        caption    => 'Fractions',
+        label      => 'vulgar_fractions_multiplication',
+        header     => [ [ 'Vulgar Fraction Multiplication', 'Vulgar Fraction Division' ] ],
+        solutions  => [],
+        challenges => [],
+    };
 
     foreach my $line (@tasks)
     {
@@ -147,14 +143,15 @@ sub _build_exercises
             }
 
             my $s = VulFrac->new(
-                                num   => $a_mult_b->( $op, $a->sign * $a->num, $b->sign * $b->num ),
-                                denum => $a_mult_b->( $op, $a->denum,          $b->denum ) );
+                num   => $a_mult_b->( $op, $a->sign * $a->num, $b->sign * $b->num ),
+                denum => $a_mult_b->( $op, $a->denum,          $b->denum )
+            );
             push @way, $s;
             $s = VulFrac->new(
-                               num   => int( $s->num ),
-                               denum => int( $s->denum ),
-                               sign  => $s->sign
-                             );
+                num   => int( $s->num ),
+                denum => int( $s->denum ),
+                sign  => $s->sign
+            );
             push @way, $s;
 
             $s->_gcd > 1 and $s = $s->_reduce and push @way, $s;
@@ -168,7 +165,7 @@ sub _build_exercises
         push( @{ $exercises->{challenges} }, \@challenge );
     }
 
-    return $exercises;
+    $exercises;
 }
 
 =head1 LICENSE AND COPYRIGHT
